import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import AtomButton from '@s-ui/react-atom-button';
import * as pagination from './helpers/pagination';
import { isValidPage, isValidTotalPages, isValidShowPages } from './customPropTypes';
var BASE_CLASS = 'sui-MoleculePagination';
var CLASS_PREV_BUTTON_ICON = 'sui-MoleculePagination-prevButtonIcon';
var CLASS_NEXT_BUTTON_ICON = 'sui-MoleculePagination-nextButtonIcon';
var PAGE_NUMBER_HOLDER = '%{pageNumber}';

var PageButton = function PageButton(_ref) {
  var onSelectPage = _ref.onSelectPage,
      page = _ref.page,
      design = _ref.design,
      props = _objectWithoutPropertiesLoose(_ref, ["onSelectPage", "page", "design"]);

  var _onSelectPage = function _onSelectPage(e) {
    onSelectPage(e, {
      page: page
    });
  };

  return React.createElement("li", {
    className: BASE_CLASS + "-item"
  }, React.createElement(AtomButton, Object.assign({
    onClick: _onSelectPage,
    design: design
  }, props)));
};

var defaultCreateUrl = function defaultCreateUrl(_ref2) {
  var pageNumber = _ref2.pageNumber,
      urlPattern = _ref2.urlPattern;
  return urlPattern.replace(PAGE_NUMBER_HOLDER, pageNumber);
};

var MoleculePagination = function MoleculePagination(_ref3) {
  var _ref3$onSelectNext = _ref3.onSelectNext,
      onSelectNext = _ref3$onSelectNext === void 0 ? function () {} : _ref3$onSelectNext,
      _ref3$onSelectPage = _ref3.onSelectPage,
      onSelectPage = _ref3$onSelectPage === void 0 ? function () {} : _ref3$onSelectPage,
      _ref3$onSelectPrev = _ref3.onSelectPrev,
      onSelectPrev = _ref3$onSelectPrev === void 0 ? function () {} : _ref3$onSelectPrev,
      page = _ref3.page,
      totalPages = _ref3.totalPages,
      _ref3$showPages = _ref3.showPages,
      showPages = _ref3$showPages === void 0 ? 10 : _ref3$showPages,
      _ref3$prevButtonText = _ref3.prevButtonText,
      prevButtonText = _ref3$prevButtonText === void 0 ? 'Previous' : _ref3$prevButtonText,
      PrevButtonIcon = _ref3.prevButtonIcon,
      _ref3$nextButtonText = _ref3.nextButtonText,
      nextButtonText = _ref3$nextButtonText === void 0 ? 'Next' : _ref3$nextButtonText,
      NextButtonIcon = _ref3.nextButtonIcon,
      _ref3$compressed = _ref3.compressed,
      compressed = _ref3$compressed === void 0 ? false : _ref3$compressed,
      hideDisabled = _ref3.hideDisabled,
      _ref3$selectedPageBut = _ref3.selectedPageButtonDesign,
      selectedPageButtonDesign = _ref3$selectedPageBut === void 0 ? 'solid' : _ref3$selectedPageBut,
      _ref3$nonSelectedPage = _ref3.nonSelectedPageButtonDesign,
      nonSelectedPageButtonDesign = _ref3$nonSelectedPage === void 0 ? 'flat' : _ref3$nonSelectedPage,
      _ref3$prevButtonDesig = _ref3.prevButtonDesign,
      prevButtonDesign = _ref3$prevButtonDesig === void 0 ? 'flat' : _ref3$prevButtonDesig,
      _ref3$nextButtonDesig = _ref3.nextButtonDesign,
      nextButtonDesign = _ref3$nextButtonDesig === void 0 ? 'flat' : _ref3$nextButtonDesig,
      linkFactory = _ref3.linkFactory,
      _ref3$createUrl = _ref3.createUrl,
      createUrl = _ref3$createUrl === void 0 ? defaultCreateUrl : _ref3$createUrl,
      _ref3$urlPattern = _ref3.urlPattern,
      urlPattern = _ref3$urlPattern === void 0 ? '#' : _ref3$urlPattern,
      _ref3$renderLinks = _ref3.renderLinks,
      renderLinks = _ref3$renderLinks === void 0 ? false : _ref3$renderLinks;
  var paramsPagination = {
    page: page,
    totalPages: totalPages,
    showPages: showPages
  };

  var handleClickNext = function handleClickNext(e) {
    var page = pagination.nextPage(paramsPagination);
    onSelectNext(e, {
      page: page
    });
  };

  var handleClickPrev = function handleClickPrev(e) {
    var page = pagination.prevPage(paramsPagination);
    onSelectPrev(e, {
      page: page
    });
  };

  var range = pagination.range(paramsPagination);
  var nextPage = pagination.nextPage(paramsPagination);
  var prevPage = pagination.prevPage(paramsPagination);
  var isHidePrev = hideDisabled && !prevPage;
  var isHideNext = hideDisabled && !nextPage;

  var linkProps = function linkProps(pageNumber) {
    return renderLinks && _extends({
      link: true,
      href: createUrl({
        pageNumber: pageNumber,
        urlPattern: urlPattern
      })
    }, linkFactory && {
      linkFactory: linkFactory
    });
  };

  return React.createElement("ul", {
    className: BASE_CLASS
  }, !isHidePrev && React.createElement("li", {
    className: BASE_CLASS + "-item"
  }, React.createElement(AtomButton, Object.assign({
    onClick: handleClickPrev,
    design: prevButtonDesign,
    disabled: !prevPage
  }, linkProps(prevPage)), PrevButtonIcon && React.createElement("span", {
    className: CLASS_PREV_BUTTON_ICON
  }, React.createElement(PrevButtonIcon, null)), prevButtonText)), compressed ? React.createElement(PageButton, Object.assign({
    page: page,
    design: selectedPageButtonDesign,
    onSelectPage: onSelectPage
  }, linkProps(page)), page) : range.map(function (pageRange) {
    return React.createElement(PageButton, Object.assign({
      key: pageRange,
      page: pageRange,
      design: pageRange === page ? selectedPageButtonDesign : nonSelectedPageButtonDesign,
      onSelectPage: onSelectPage
    }, linkProps(pageRange)), pageRange);
  }), !isHideNext && React.createElement("li", {
    className: BASE_CLASS + "-item"
  }, React.createElement(AtomButton, Object.assign({
    onClick: handleClickNext,
    design: nextButtonDesign,
    disabled: !nextPage
  }, linkProps(nextPage)), nextButtonText, NextButtonIcon && React.createElement("span", {
    className: CLASS_NEXT_BUTTON_ICON
  }, React.createElement(NextButtonIcon, null)))));
};

MoleculePagination.displayName = 'MoleculePagination';
export default MoleculePagination;